--
-- MasseyFerguson DynaVT 8670 BR

--@author       Slavo LS ()
-- @version     v2.0
-- @date        03.03.2018
-- @history:    v1.0 - Initial version
--              v2.0 - Additional edits by Esdras Ls (Tech Farm Modding)
--

dynavt8670 = {};

function dynavt8670.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function dynavt8670:load(xmlFile)
	self.cu = false;
	self.uvg = false;
	self.m = 1;

	self.variogrip = true;
	self.hasVarioGrip = true;

	self.seatSusp = false;

	--self.podsvietenie = Utils.indexToObject(self.components, "0>4|1|4|1");
	
	self.GreenStarPraca = Utils.indexToObject(self.components, "0>11|0|13|9");

	self.svetla = Utils.indexToObject(self.components, "0>11|0|13");

	self.PanelHudTime = Utils.indexToObject(self.components, "0>11|0|13|3");
	self.PanelHudKMh = Utils.indexToObject(self.components, "0>11|0|13|7");
	self.PanelHudRpm1 = Utils.indexToObject(self.components, "0>11|0|13|8");

	print("  Massey Ferguson DynaVT 8670 V1.1.0.0");

	setVisibility(self.GreenStarPraca, false);
	setVisibility(self.PanelHudTime, false);
	setVisibility(self.PanelHudKMh, false);
	setVisibility(self.PanelHudRpm1, false);

	self.suspFront = self.wheels[1].suspTravel;
	self.suspBack = self.wheels[3].suspTravel;

	self.deformFront = self.wheels[1].maxDeformation;
	self.deformBack = self.wheels[3].maxDeformation;

	self.frictionFront = self.wheels[1].frictionScale;
	self.frictionBack = self.wheels[3].frictionScale;
end;

function dynavt8670:delete()
end;

function dynavt8670:readStream(streamId, connection)
end;

function dynavt8670:writeStream(streamId, connection)
end;

function dynavt8670:mouseEvent(posX, posY, isDown, isUp, button)
end;

function dynavt8670:keyEvent(unicode, sym, modifier, isDown)
end;

function dynavt8670:update(dt)

	if self.isMotorStarted then
		if(self.seatSusp) then
			setTranslation(self.seatID, self.startSeatXTranslation, self.startSeatYTranslation+self.wheels[4].deltaY, self.startSeatZTranslation);
		end;

		if InputBinding.hasEvent(InputBinding.VarioGrip) then
			if (self.hasVarioGrip) then
				self.variogrip = not self.variogrip;
				self.uvg = true;
				if (self.variogrip) then t = 3; else t = 1; end;
			end;
		end;

		if(self.uvg == true) then
		    for i, wheel in ipairs(self.wheels) do
		    	if(self.variogrip) then

		    		if(self.deformFront*t > wheel.maxDeformation) then
		    			self.m = self.m+0.001;

			    		if((i == 1) or (i == 2)) then
			    			wheel.maxDeformation = self.deformFront*self.m;
			    			wheel.frictionScale = self.frictionFront*self.m;
			    		else 
			    			wheel.maxDeformation = self.deformBack*self.m;
			    			wheel.frictionScale = self.frictionBack*self.m;
			    		end;
			    		wheel.suspTravel = wheel.suspTravel - (self.m / 10000);
			    		self:updateWheelTireFriction(wheel);
			    		self:updateWheelBase(wheel);
			    	else
			    		self.uvg = false;
		    		end;
		    	else
		    		if(self.deformFront*t < wheel.maxDeformation) then
		    			self.m = self.m-0.001;

			    		if((i == 1) or (i == 2)) then
			    			wheel.maxDeformation = self.deformFront*self.m;
			    			wheel.frictionScale = self.frictionFront*self.m;
			    		else 
			    			wheel.maxDeformation = self.deformBack*self.m;
			    			wheel.frictionScale = self.frictionBack*self.m;
			    		end;
			    		wheel.suspTravel = wheel.suspTravel + (self.m / 10000);
			    		self:updateWheelTireFriction(wheel);
			    		self:updateWheelBase(wheel);
		    		else 
						self.uvg = false;
		    		end;
		    	end;
			end;

		end;
	end;

end;

function dynavt8670:updateTick(dt)

   if self:getIsActive() then
		if self.isMotorStarted then

			setVisibility(self.GreenStarPraca, false);
			setVisibility(self.PanelHudTime, true);
			setVisibility(self.PanelHudKMh, true);
			setVisibility(self.PanelHudRpm1, true);

			--if( getVisibility(self.svetla) == true ) then
			--	setVisibility(self.dashlight, true);
			--else
			--	setVisibility(self.dashlight, false);
			--end;
		else
			setVisibility(self.GreenStarPraca, false);
			setVisibility(self.PanelHudTime, false);
			setVisibility(self.PanelHudKMh, false);
			setVisibility(self.PanelHudRpm1, false);
		end;
	end;
end;

function dynavt8670:draw()
end;

function dynavt8670:onLeave()
end;

function dynavt8670:onEnter()
end;